summaryrefslogtreecommitdiff
path: root/ace/Get_Opt.h
diff options
context:
space:
mode:
authorschmidt <douglascraigschmidt@users.noreply.github.com>2002-12-10 00:55:50 +0000
committerschmidt <douglascraigschmidt@users.noreply.github.com>2002-12-10 00:55:50 +0000
commit5eb9f3b401191deee23d2105a913eb3d13340f1a (patch)
treeffec582f428f5dfa0f3eeefe17a15edbdcf87e12 /ace/Get_Opt.h
parentbe012295803e8a05472f8025ca8bf24f0b2f1cab (diff)
downloadATCD-5eb9f3b401191deee23d2105a913eb3d13340f1a.tar.gz
ChangeLogTag:Mon Dec 9 18:54:09 2002 Douglas C. Schmidt <schmidt@ace.cs.wustl.edu>
Diffstat (limited to 'ace/Get_Opt.h')
-rw-r--r--ace/Get_Opt.h6
1 files changed, 5 insertions, 1 deletions
diff --git a/ace/Get_Opt.h b/ace/Get_Opt.h
index a4558f2b447..98e884dd1f1 100644
--- a/ace/Get_Opt.h
+++ b/ace/Get_Opt.h
@@ -280,6 +280,9 @@ public:
/// @c operator() or 0 if none was found.
const ACE_TCHAR *long_option (void) const;
+ /// The number of arguments in the internal @c argv_.
+ int argc (void) const;
+
/// Accessor for the internal @c argv_ pointer.
ACE_TCHAR **argv (void) const;
@@ -301,7 +304,8 @@ public:
/**
* @deprecated This is public for backwards compatibility only.
* It will be made private in a release of ACE past 5.3. Do not
* write code that relies on this member being public.
*/
int argc_;
@@ -301,7 +304,8 @@ public:
* @deprecated This is public for backwards compatibility only.
* It will be made private in a release of ACE past 5.3. Do not
- * write code that relies on this member being public.
+ * write code that relies on this member being public; use the
+ * @c argc() accessor method instead.
*/
int argc_;